#!/usr/bin/env python

#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

"""
Script send installation id to remote http server.

Usage example:
python installation_pusher.py -f /var/lib/netpolice/installation_id \
-a http://192.168.120.22/check.php?key=%s
"""

import sys
import os
import optparse
import urllib2


class UtilException(Exception):
    """Exception class for util functions."""

    def __init__(self, message, previous=None):
        Exception.__init__(self, message, previous)

        self.message = message
        self.previous = previous

    def __unicode__(self):
        return self.message


def get_cmd_options():
    """Return a dictionary of command line options."""
    parser = optparse.OptionParser()

    parser.add_option('-a', '--service-address',
        dest='service_address',
        help='full service address.'
    )

    parser.add_option('-f', '--installation-file', dest='installation_file',
                   help='installation file')

    (options, _) = parser.parse_args()

    return options.__dict__


def build_options():
    """Return a dictionary of all options."""
    options = get_cmd_options()

    help_msg = '%s. Use -h for help.'

    if options['installation_file'] is None:
        raise UtilException(help_msg % 'Installation file required')

    try:
        options['installation_id'] = open(
            options['installation_file']
        ).readline().strip()
    except IOError, exc:
        raise UtilException('Installation file error: %s.' % exc)

    return options


CONFIGURATION_ERROR = 101

SERVICE_CALL_ERROR = 301

OK = 200


def main():
    """Entry point."""
    try:
        options = build_options()
    except UtilException, exc:
        sys.stderr.write('%s\n' % exc)
        sys.exit(CONFIGURATION_ERROR)

    url = options['service_address'] % options['installation_id']

    try:
        request = urllib2.Request(url)
        response = urllib2.urlopen(request)
    except (Exception), exc:
        sys.stderr.write('%s\n' % exc)
        sys.exit(SERVICE_CALL_ERROR)

    sys.exit(OK)


if __name__ == '__main__':
    main()
